/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb;

import java.awt.Rectangle;
import java.awt.geom.AffineTransform;
import java.io.File;
import java.io.IOException;

import de.jave.kicad.pcb.model.KicadBoard;
import de.jave.kicad.pcb.model.KicadBoardContent;
import de.jave.kicad.pcb.model.PositioningTransformation;
import de.jave.kicad.pcb.persistence.read.KicadPcbFileParser;
import de.jave.kicad.pcb.persistence.write.KicadPcbFileWriter;

public class PcbManipulationMain {

  public static void main(final String[] args) throws IOException {
    final File file = new File("./example/vq10_testboard.brd"); //$NON-NLS-1$

    final KicadBoard board = KicadPcbFileParser.parse(file);

    final Rectangle boardBounds = board.getPcbOutlineOrContentBounds();

    final KicadBoardContent content = board.getContent();

    final AffineTransform t = new AffineTransform();
    t.translate(boardBounds.width, 0);
    t.translate(boardBounds.x, boardBounds.y);
    t.rotate(Math.PI / 2.0, 0, boardBounds.height);
    t.translate(-boardBounds.height, 0);
    t.translate(-boardBounds.x, -boardBounds.y);
    //    t.translate(dx, dy);
    //    t.translate(boardBounds.x, boardBounds.y);
    final KicadBoardContent translatedContent = content
        .deriveTransformed(new PositioningTransformation(t, 90));
    board.addContent(translatedContent);

    final File outputFile = new File("./example/vq10_testboard_pcboptimizer.brd"); //$NON-NLS-1$
    board.setFile(outputFile);
    KicadPcbFileWriter.write(board);
  }
}