/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.manipulate;

import java.util.ArrayList;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.model.Block;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class BlockFinder {

  public static Block getFirstRequiredBlock(final Block block, final String blockName) {
    final Block subBlock = getFirstBlock(block, blockName);
    if (subBlock != null) {
      return subBlock;
    }
    throw new IllegalStateException("missing required block '" //$NON-NLS-1$
        + blockName
        + "' in '" //$NON-NLS-1$
        + block.getBlockName()
        + "'"); //$NON-NLS-1$
  }

  public static Block getFirstBlock(final Block block, final String blockName) {
    for (final IBlockItem item : block.getItems()) {
      if (item instanceof BlockBlockItem) {
        final BlockBlockItem blockItem = (BlockBlockItem) item;
        if (blockName.equals(blockItem.getBlock().getBlockName())) {
          return blockItem.getBlock();
        }
      }
    }
    return null;
  }

  public static List<Block> getAllBlocksByPrefix(final Block block, final String blockNamePrefix) {
    final List<BlockBlockItem> items = getAllBlockItemsByPrefix(block, blockNamePrefix);
    return CollectionUtilities.transform(items, new ITransformer<BlockBlockItem, Block>() {
      @Override
      public Block transform(final BlockBlockItem input) {
        return input.getBlock();
      }
    });
  }

  public static List<BlockBlockItem> getAllBlockItemsByPrefix(
      final Block block,
      final String blockNamePrefix) {
    final List<BlockBlockItem> items = new ArrayList<BlockBlockItem>();
    for (final IBlockItem item : block.getItems()) {
      if (item instanceof BlockBlockItem) {
        final BlockBlockItem blockItem = (BlockBlockItem) item;
        if ((blockItem.getBlock().getBlockName().startsWith(blockNamePrefix))) {
          items.add(blockItem);
        }
      }
    }
    return items;
  }
}