/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.manipulate;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import de.jave.kicad.pcb.model.Block;
import de.jave.kicad.pcb.persistence.read.IBlockItem;
import de.jave.kicad.pcb.persistence.read.LineBlockItem;

public class ParameterFinder {

  public static List<String> getAllLineContents(final Block block) {
    final List<String> list = new ArrayList<String>();
    for (final IBlockItem item : block.getItems()) {
      if (item instanceof LineBlockItem) {
        final LineBlockItem lineIntem = (LineBlockItem) item;
        final String line = lineIntem.getLine();
        list.add(line);
      }
    }
    return list;
  }

  public static List<String> getAllParameterLineContents(
      final Block block,
      final String parameterName) {
    final List<String> list = new ArrayList<String>();
    for (final IBlockItem item : block.getItems()) {
      if (item instanceof LineBlockItem) {
        final LineBlockItem lineIntem = (LineBlockItem) item;
        final String line = lineIntem.getLine();
        if (line.startsWith(parameterName + " ")) { //$NON-NLS-1$
          list.add(line.substring(parameterName.length() + 1));
        }
      }
    }
    return list;
  }

  public static String getRequiredParameterLineContent(final Block block, final String parameterName) {
    for (final IBlockItem item : block.getItems()) {
      if (item instanceof LineBlockItem) {
        final LineBlockItem lineIntem = (LineBlockItem) item;
        final String line = lineIntem.getLine();
        if (line.startsWith(parameterName + " ")) { //$NON-NLS-1$
          return line.substring(parameterName.length() + 1);
        }
      }
    }
    throw new IllegalStateException("No parameter '" //$NON-NLS-1$
        + parameterName
        + "' found in block '" //$NON-NLS-1$
        + block.getBlockName()
        + "'"); //$NON-NLS-1$
  }

  public static void replaceParameterContent(
      final Block block,
      final String parameterName,
      final String content) {
    final String newLine = parameterName + ' ' + content;
    final List<IBlockItem> items = block.getItems();
    for (int i = 0; i < items.size(); ++i) {
      final IBlockItem item = items.get(i);
      if (item instanceof LineBlockItem) {
        final LineBlockItem lineIntem = (LineBlockItem) item;
        final String line = lineIntem.getLine();
        if (line.startsWith(parameterName + " ")) { //$NON-NLS-1$
          items.set(i, new LineBlockItem(newLine));
          return;
        }
      }
    }
    throw new IllegalStateException("No parameter '" //$NON-NLS-1$
        + parameterName
        + "' found in block '" //$NON-NLS-1$
        + block.getBlockName()
        + "'"); //$NON-NLS-1$
  }

  public static void replaceParameterContent(
      final Block block,
      final String parameterName,
      final List<String> contents) {
    final List<IBlockItem> items = block.getItems();
    int startBlockIndex = -1;
    int currentBlockIndex = 0;
    final Iterator<IBlockItem> iterator = items.iterator();
    while (iterator.hasNext()) {
      final IBlockItem item = iterator.next();
      if (item instanceof LineBlockItem) {
        final LineBlockItem lineIntem = (LineBlockItem) item;
        final String line = lineIntem.getLine();
        if (line.startsWith(parameterName + " ")) { //$NON-NLS-1$
          iterator.remove();
          if (startBlockIndex == -1) {
            startBlockIndex = currentBlockIndex;
          }
        }
      }
      ++currentBlockIndex;
    }

    for (int i = 0; i < contents.size(); ++i) {
      items.add(startBlockIndex + i, new LineBlockItem(parameterName + " " + contents.get(i))); //$NON-NLS-1$
    }
  }

  public static void replaceAllLines(final Block block, final List<String> contents) {
    final List<IBlockItem> items = block.getItems();
    int startBlockIndex = -1;
    int currentBlockIndex = 0;
    final Iterator<IBlockItem> iterator = items.iterator();
    while (iterator.hasNext()) {
      final IBlockItem item = iterator.next();
      if (item instanceof LineBlockItem) {
        iterator.remove();
        if (startBlockIndex == -1) {
          startBlockIndex = currentBlockIndex;
        }
      }
      ++currentBlockIndex;
    }

    for (int i = 0; i < contents.size(); ++i) {
      items.add(startBlockIndex + i, new LineBlockItem(contents.get(i)));
    }
  }
}