/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.ArrayList;
import java.util.List;

import net.disy.commons.core.util.Ensure;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public final class Block implements Cloneable {

  private final String blockName;
  private final List<IBlockItem> items;

  public Block(final String blockName, final List<IBlockItem> items) {
    Ensure.ensureArgumentNotNull(blockName);
    Ensure.ensureArgumentNotNull(items);
    this.items = items;
    this.blockName = blockName;
  }

  @Override
  public Block clone() {
    final List<IBlockItem> clonedItems = new ArrayList<IBlockItem>();
    for (final IBlockItem item : items) {
      clonedItems.add(item.clone());
    }
    return new Block(blockName, clonedItems);
  }

  public final List<IBlockItem> getItems() {
    return items;
  }

  public final String getBlockName() {
    return blockName;
  }
}