/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.awt.Rectangle;

import net.disy.commons.core.util.Ensure;
import de.jave.kicad.pcb.manipulate.BlockDecoder;
import de.jave.kicad.pcb.persistence.IKicadConstants;

public class DrawSegment {

  private final Block block;

  //TODO_NOW (gebhard) 20.01.2011: since we know how to decode DrawSegentPositon and ~Description we can parse it and do not need to know the block in here
  public DrawSegment(final Block block) {
    Ensure.ensureArgumentNotNull(block);
    this.block = block;
  }

  public Block getBlock() {
    return block;
  }

  public DrawSegment deriveTransformed(final PositioningTransformation t) {
    final Block clone = block.clone();
    final DrawSegmentPosition position = BlockDecoder.getDrawSegmentPosition(clone);
    final DrawSegmentPosition newPosition = position.deriveTransformed(t);
    BlockDecoder.setDrawSegmentPosition(clone, newPosition);
    return new DrawSegment(clone);
  }

  public Rectangle getBounds() {
    final DrawSegmentPosition position = BlockDecoder.getDrawSegmentPosition(block);
    final int x1 = position.getxStart();
    final int y1 = position.getyStart();
    final int x2 = position.getxEnd();
    final int y2 = position.getyEnd();
    final int x = Math.min(x1, x2) - position.getWidth() / 2;
    final int y = Math.min(y1, y2) - position.getWidth() / 2;
    final int width = Math.abs(x1 - x2) + position.getWidth();
    final int height = Math.abs(y1 - y2) + position.getWidth();
    return new Rectangle(x, y, width, height);
  }

  public boolean isPcbEdge() {
    final DrawSegmentDescription description = BlockDecoder.getDrawSegmentDescription(block);
    final int layer = description.getLayer();
    return layer == IKicadConstants.LAYER_EDGES_PCB;
  }
}