/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.awt.Rectangle;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class DrawSegmentList {

  private final List<DrawSegment> drawSegments;

  public DrawSegmentList(final List<DrawSegment> drawSegments) {
    Ensure.ensureArgumentNotNull(drawSegments);
    this.drawSegments = drawSegments;
  }

  public List<DrawSegment> getDrawSegments() {
    return drawSegments;
  }

  public DrawSegmentList deriveTransformed(final PositioningTransformation t) {
    final List<DrawSegment> transformedSegments = CollectionUtilities.transform(
        drawSegments,
        new ITransformer<DrawSegment, DrawSegment>() {
          @Override
          public DrawSegment transform(final DrawSegment segment) {
            return segment.deriveTransformed(t);
          }
        });
    return new DrawSegmentList(transformedSegments);
  }

  public List<IBlockItem> getBlockItems() {
    final List<IBlockItem> items = CollectionUtilities.transform(
        drawSegments,
        new ITransformer<DrawSegment, IBlockItem>() {
          @Override
          public IBlockItem transform(final DrawSegment input) {
            return new BlockBlockItem(input.getBlock());
          }
        });
    return items;
  }

  public Rectangle getMaxBounds() {
    final MaxBoundsBuilder builder = new MaxBoundsBuilder();
    for (final DrawSegment drawSegment : drawSegments) {
      builder.add(drawSegment.getBounds());
    }
    return builder.getBounds();
  }

  public Rectangle getPcbEdgesBounds() {
    final MaxBoundsBuilder builder = new MaxBoundsBuilder();
    for (final DrawSegment drawSegment : drawSegments) {
      if (drawSegment.isPcbEdge()) {
        builder.add(drawSegment.getBounds());
      }
    }
    return builder.getBounds();
  }
}