/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.awt.Rectangle;

import net.disy.commons.core.util.Ensure;

public class KicadBoardContent {

  private final ModuleList modules;
  private final TracksAndVias tracksOrVias;
  private final ZoneList zones;
  private final TextList texts;
  private final DrawSegmentList drawSegments;

  public KicadBoardContent(
      final ModuleList modules,
      final DrawSegmentList drawSegments,
      final TextList texts,
      final ZoneList zones,
      final TracksAndVias tracksOrVias) {
    Ensure.ensureArgumentNotNull(modules);
    Ensure.ensureArgumentNotNull(drawSegments);
    Ensure.ensureArgumentNotNull(texts);
    Ensure.ensureArgumentNotNull(zones);
    Ensure.ensureArgumentNotNull(tracksOrVias);
    this.modules = modules;
    this.drawSegments = drawSegments;
    this.texts = texts;
    this.zones = zones;
    this.tracksOrVias = tracksOrVias;
  }

  public ModuleList getModules() {
    return modules;
  }

  public TracksAndVias getTracksOrVias() {
    return tracksOrVias;
  }

  public ZoneList getZones() {
    return zones;
  }

  public TextList getTexts() {
    return texts;
  }

  public DrawSegmentList getDrawSegments() {
    return drawSegments;
  }

  public KicadBoardContent deriveTransformed(final PositioningTransformation t) {
    final ModuleList newModules = modules.deriveTransformed(t);
    final DrawSegmentList newDrawSegments = drawSegments.deriveTransformed(t);
    final TextList newTexts = texts.deriveTransformed(t);
    final ZoneList newZones = zones.deriveTransformed(t);
    final TracksAndVias newTracksOrVias = tracksOrVias.deriveTransformed(t);
    return new KicadBoardContent(newModules, newDrawSegments, newTexts, newZones, newTracksOrVias);
  }

  public Rectangle getMaxBounds() {
    final MaxBoundsBuilder builder = new MaxBoundsBuilder();
    // TODO_NOW add modules
    builder.add(drawSegments.getMaxBounds());
    // TODO_NOW add drawSegments
    // TODO_NOW add texts
    // TODO_NOW add zones
    // TODO_NOW add tracksOrVias
    return builder.getBounds();
  }
}