/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.manipulate.BlockDecoder;
import de.jave.kicad.pcb.manipulate.BlockFinder;
import de.jave.kicad.pcb.persistence.IKicadConstants;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class Module {

  private final Block block;

  public Module(final Block block) {
    Ensure.ensureArgumentNotNull(block);
    this.block = block;
  }

  public Module deriveTransformed(final PositioningTransformation t) {
    final Block clone = block.clone();
    final ModulePosition position = BlockDecoder.getModulePosition(clone);
    final ModulePosition newPosition = position.deriveTransformed(t);
    BlockDecoder.setModulePosition(clone, newPosition);
    final PadList pads = getPads();
    setPads(clone, pads.deriveRotated(t));
    return new Module(clone);
  }

  private static void setPads(final Block moduleBlock, final PadList padList) {
    final List<BlockBlockItem> oldItems = BlockFinder.getAllBlockItemsByPrefix(
        moduleBlock,
        IKicadConstants.TAG_PAD);
    moduleBlock.getItems().removeAll(oldItems);
    final List<IBlockItem> newItems = padList.getBlockItems();
    moduleBlock.getItems().addAll(newItems);
  }

  public PadList getPads() {
    final List<Block> padBlocks = BlockFinder.getAllBlocksByPrefix(block, IKicadConstants.TAG_PAD);
    return new PadList(CollectionUtilities.transform(padBlocks, new ITransformer<Block, Pad>() {
      @Override
      public Pad transform(final Block input) {
        return BlockDecoder.parsePad(input);
      }
    }));
  }

  public Block getBlock() {
    return block;
  }
}