/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class ModuleList {

  private final List<Module> modules;

  public ModuleList(final List<Module> modules) {
    Ensure.ensureArgumentNotNull(modules);
    this.modules = modules;
  }

  public ModuleList deriveTransformed(final PositioningTransformation t) {
    final List<Module> transformedModules = CollectionUtilities.transform(
        modules,
        new ITransformer<Module, Module>() {
          @Override
          public Module transform(final Module module) {
            return module.deriveTransformed(t);
          }
        });
    return new ModuleList(transformedModules);
  }

  public List<IBlockItem> getBlockItems() {
    final List<IBlockItem> items = CollectionUtilities.transform(
        modules,
        new ITransformer<Module, IBlockItem>() {
          @Override
          public IBlockItem transform(final Module input) {
            return new BlockBlockItem(input.getBlock());
          }
        });
    return items;
  }
}