/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.awt.Point;

import net.disy.commons.core.util.Ensure;

public class ModulePosition {

  private final int x;
  private final int y;
  private final int orientation;
  private final int layer;
  private final String s1;
  private final String s2;
  private final Placement placement;

  public ModulePosition(
      final int x,
      final int y,
      final int orientation,
      final int layer,
      final String s1,
      final String s2,
      final Placement placement) {
    Ensure.ensureArgumentNotNull(s1);
    Ensure.ensureArgumentNotNull(s2);
    Ensure.ensureArgumentNotNull(placement);
    this.x = x;
    this.y = y;
    this.orientation = orientation;
    this.layer = layer;
    this.s1 = s1;
    this.s2 = s2;
    this.placement = placement;
  }

  public ModulePosition deriveTransformed(final PositioningTransformation t) {
    final Point p = t.transform(x, y);
    final int newRotation = t.appendToKicadRotation(orientation);
    return new ModulePosition(p.x, p.y, newRotation, layer, s1, s2, placement);
  }

  public int getX() {
    return x;
  }

  public int getY() {
    return y;
  }

  public int getOrientation() {
    return orientation;
  }

  public int getLayer() {
    return layer;
  }

  public String getS1() {
    return s1;
  }

  public String getS2() {
    return s2;
  }

  public Placement getPlacement() {
    return placement;
  }
}