/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import net.disy.commons.core.util.Ensure;

public class Pad {

  private final PadDrill drill;
  private final PadShape shape;
  private final String attributesString;
  private final String netString;
  private final String positionString;

  public Pad(
      final PadShape shape,
      final PadDrill drill,
      final String attributesString,
      final String netString,
      final String positionString) {
    Ensure.ensureArgumentNotNull(shape);
    Ensure.ensureArgumentNotNull(drill);
    Ensure.ensureArgumentNotNull(attributesString);
    Ensure.ensureArgumentNotNull(netString);
    Ensure.ensureArgumentNotNull(positionString);
    this.shape = shape;
    this.drill = drill;
    this.attributesString = attributesString;
    this.netString = netString;
    this.positionString = positionString;
  }

  public Pad deriveRotated(final PositioningTransformation t) {
    final PadShape rotatedShape = shape.deriveRotated(t);
    return new Pad(rotatedShape, drill, attributesString, netString, positionString);
  }

  public PadDrill getDrill() {
    return drill;
  }

  public PadShape getShape() {
    return shape;
  }

  public String getAttributesString() {
    return attributesString;
  }

  public String getNetString() {
    return netString;
  }

  public String getPositionString() {
    return positionString;
  }
}