/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.manipulate.BlockDecoder;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class PadList {

  private final List<Pad> pads;

  public PadList(final List<Pad> pads) {
    Ensure.ensureArgumentNotNull(pads);
    this.pads = pads;
  }

  public List<Pad> getPads() {
    return pads;
  }

  public PadList deriveRotated(final PositioningTransformation t) {
    final List<Pad> transformedPads = CollectionUtilities.transform(
        pads,
        new ITransformer<Pad, Pad>() {
          @Override
          public Pad transform(final Pad input) {
            return input.deriveRotated(t);
          }
        });
    return new PadList(transformedPads);
  }

  public List<IBlockItem> getBlockItems() {
    return CollectionUtilities.transform(
        pads,
        new ITransformer<Pad, IBlockItem>() {
          @Override
          public IBlockItem transform(final Pad input) {
            return new BlockBlockItem(BlockDecoder.encodePad(input));
          }
        });
  }
}