/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import net.disy.commons.core.util.Ensure;

public class PadShape {

  private final int orientation;
  private final int yDelta;
  private final int xDelta;
  private final int ySize;
  private final int xSize;
  private final String shape;
  private final String name;

  public PadShape(
      final String name,
      final String shape,
      final int xSize,
      final int ySize,
      final int xDelta,
      final int yDelta,
      final int orientation) {
    Ensure.ensureArgumentNotNull(name);
    Ensure.ensureArgumentNotNull(shape);
    this.name = name;
    this.shape = shape;
    this.xSize = xSize;
    this.ySize = ySize;
    this.xDelta = xDelta;
    this.yDelta = yDelta;
    this.orientation = orientation;
  }

  public int getOrientation() {
    return orientation;
  }

  public int getyDelta() {
    return yDelta;
  }

  public int getxDelta() {
    return xDelta;
  }

  public int getySize() {
    return ySize;
  }

  public int getxSize() {
    return xSize;
  }

  public String getShape() {
    return shape;
  }

  public String getName() {
    return name;
  }

  public PadShape deriveRotated(final PositioningTransformation t) {
    final int newOrientationRotation = t.appendToKicadRotation(orientation);
    return new PadShape(name, shape, xSize, ySize, xDelta, yDelta, newOrientationRotation);
  }
}