/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.awt.Point;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;

import net.disy.commons.core.util.Ensure;

public class PositioningTransformation {

  private final AffineTransform at;
  private final int rotationAngle;

  public PositioningTransformation(final AffineTransform at, final int rotationAngle) {
    Ensure.ensureArgumentNotNull(at);
    this.at = at;
    this.rotationAngle = rotationAngle;
  }

  public Point transform(final int x, final int y) {
    final Point2D.Double tmpPoint = new Point2D.Double();
    at.transform(new Point2D.Double(x, y), tmpPoint);
    return new Point((int) Math.round(tmpPoint.x), (int) Math.round(tmpPoint.y));
  }

  public void transform(final int[] xs, final int[] ys, final int pointCount) {
    final Point2D.Double tmpPoint = new Point2D.Double();
    for (int i = 0; i < pointCount; ++i) {
      at.transform(new Point2D.Double(xs[i], ys[i]), tmpPoint);
      xs[i] = (int) Math.round(tmpPoint.x);
      ys[i] = (int) Math.round(tmpPoint.y);
    }
  }

  public int appendToKicadRotation(final int orientation) {
    final int newOrientation = orientation - rotationAngle * 10;
    if (newOrientation < 0) {
      return newOrientation + 3600;
    }
    return newOrientation;
  }

  public int getRotationAngle() {
    return rotationAngle;
  }
}