/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class TextList {

  private final List<Text> texts;

  public TextList(final List<Text> texts) {
    Ensure.ensureArgumentNotNull(texts);
    this.texts = texts;
  }

  public List<Text> getTexts() {
    return texts;
  }

  public TextList deriveTransformed(final PositioningTransformation t) {
    final List<Text> transformedSegments = CollectionUtilities.transform(
        texts,
        new ITransformer<Text, Text>() {
          @Override
          public Text transform(final Text text) {
            return text.deriveTransformed(t);
          }
        });
    return new TextList(transformedSegments);
  }

  public List<IBlockItem> getBlockItems() {
    final List<IBlockItem> items = CollectionUtilities.transform(
        texts,
        new ITransformer<Text, IBlockItem>() {
          @Override
          public IBlockItem transform(final Text input) {
            return new BlockBlockItem(input.getBlock());
          }
        });
    return items;
  }
}