/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;

public class TracksAndVias {

  private final List<TrackOrVia> entries;

  public TracksAndVias(final List<TrackOrVia> entries) {
    Ensure.ensureArgumentNotNull(entries);
    this.entries = entries;
  }

  public List<TrackOrVia> getEntries() {
    return entries;
  }

  public TracksAndVias deriveTransformed(final PositioningTransformation t) {
    final List<TrackOrVia> newTracksOrVias = CollectionUtilities.transform(
        entries,
        new ITransformer<TrackOrVia, TrackOrVia>() {
          @Override
          public TrackOrVia transform(final TrackOrVia input) {
            return input.deriveTransformed(t);
          }
        });
    return new TracksAndVias(newTracksOrVias);
  }
}