/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.manipulate.BlockDecoder;
import de.jave.kicad.pcb.manipulate.BlockFinder;

public class Zone {

  private final Block block;

  public Zone(final Block block) {
    Ensure.ensureArgumentNotNull(block);
    this.block = block;
  }

  public Block getBlock() {
    return block;
  }

  public Zone deriveTransformed(final PositioningTransformation t) {
    final Block clone = block.clone();
    final List<ZCorner> zCorners = BlockDecoder.getZCorners(clone);
    final List<ZCorner> newZCorners = CollectionUtilities.transform(
        zCorners,
        new ITransformer<ZCorner, ZCorner>() {
          @Override
          public ZCorner transform(final ZCorner input) {
            return input.deriveTransformed(t);
          }
        });
    BlockDecoder.setZCorners(clone, newZCorners);

    final List<Block> polysCornersBlocks = BlockFinder.getAllBlocksByPrefix(clone, "POLYSCORNERS"); //$NON-NLS-1$
    for (final Block polysCornerBlock : polysCornersBlocks) {
      final List<PolysCorner> polysCorners = BlockDecoder.getPolysCorners(polysCornerBlock);
      final List<PolysCorner> newPolysCorners = CollectionUtilities.transform(
          polysCorners,
          new ITransformer<PolysCorner, PolysCorner>() {
            @Override
            public PolysCorner transform(final PolysCorner input) {
              return input.deriveTransformed(t);
            }
          });
      BlockDecoder.setPolysCorners(polysCornerBlock, newPolysCorners);
    }
    final List<Block> fillSegmentBlocks = BlockFinder.getAllBlocksByPrefix(clone, "FILLSEGMENTS"); //$NON-NLS-1$
    for (final Block fillSegmentBlock : fillSegmentBlocks) {
      final List<FillSegment> fillSegments = BlockDecoder.getFillSegments(fillSegmentBlock);
      final List<FillSegment> newFillSegments = CollectionUtilities.transform(
          fillSegments,
          new ITransformer<FillSegment, FillSegment>() {
            @Override
            public FillSegment transform(final FillSegment input) {
              return input.deriveTransformed(t);
            }
          });
      BlockDecoder.setFillSegments(fillSegmentBlock, newFillSegments);
    }
    return new Zone(clone);
  }
}