/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.model;

import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;

public class ZoneList {

  private final List<Zone> modules;

  public ZoneList(final List<Zone> modules) {
    Ensure.ensureArgumentNotNull(modules);
    this.modules = modules;
  }

  public ZoneList deriveTransformed(final PositioningTransformation t) {
    final List<Zone> transformedModules = CollectionUtilities.transform(
        modules,
        new ITransformer<Zone, Zone>() {
          @Override
          public Zone transform(final Zone zone) {
            return zone.deriveTransformed(t);
          }
        });
    return new ZoneList(transformedModules);
  }

  public List<IBlockItem> getBlockItems() {
    final List<IBlockItem> items = CollectionUtilities.transform(
        modules,
        new ITransformer<Zone, IBlockItem>() {
          @Override
          public IBlockItem transform(final Zone input) {
            return new BlockBlockItem(input.getBlock());
          }
        });
    return items;
  }
}