/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.persistence.read;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;

import net.disy.commons.core.io.IOUtilities;
import de.jave.kicad.pcb.ParseException;
import de.jave.kicad.pcb.model.Block;
import de.jave.kicad.pcb.model.KicadBoard;

public class KicadPcbFileParser {

  public static KicadBoard parse(final File file) throws IOException {
    final KicadPcbInterpreter parser = new KicadPcbInterpreter();
    FileReader fileReader = null;
    try {
      fileReader = new FileReader(file);
      final BufferedReader reader = new BufferedReader(fileReader);
      String line;
      int lineIndex = 0;
      while ((line = reader.readLine()) != null) {
        ++lineIndex;
        parser.parseLine(lineIndex, line);
      }
    }
    catch (final ParseException e) {
      throw new IOException("Error parsing file '" + file.getAbsolutePath() + "'", e); //$NON-NLS-1$ //$NON-NLS-2$
    }
    finally {
      IOUtilities.close(fileReader);
    }
    final Block rootBlock = parser.createObject();
    return new KicadBoard(file, rootBlock);
  }
}