/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.persistence.read;

import java.io.IOException;
import java.util.Stack;

import net.disy.commons.core.util.StringUtilities;
import de.jave.kicad.pcb.ParseException;
import de.jave.kicad.pcb.model.Block;
import de.jave.kicad.pcb.persistence.IKicadConstants;

public class KicadPcbInterpreter {

  private final Stack<BlockBuilder> builders = new Stack<BlockBuilder>() {
    {
      add(new BlockBuilder(IKicadConstants.TAG_BOARD));
    }
  };
  private Block board;

  public void parseLine(final int lineIndex, final String line) throws ParseException {
    try {
      if (StringUtilities.startsWithIgnoreCase(line, "$end")) {
        final String blockName = line.substring(4);
        if (builders.isEmpty()) {
          throw new IOException("End tag '" + blockName + "' without start");
        }

        final BlockBuilder builder = builders.peek();

        if (builders.isEmpty()) {
          throw new IOException("end tag without block started"); //$NON-NLS-1$
        }
        builders.pop();

        if (IKicadConstants.TAG_BOARD.equals(builder.getBlockName())) {
          if (board != null) {
            throw new IOException();
          }
          board = builder.createBlock();
        }
        else {
          final Block block = builder.createBlock();
          builders.peek().addSubBlock(block);
        }
        if (!isEquivalentBlockName(blockName, builder.getBlockName())) {
          throw new IOException("End tag '" //$NON-NLS-1$
              + blockName
              + "' does not fit start tag '" //$NON-NLS-1$
              + builder.getBlockName()
              + "'."); //$NON-NLS-1$
        }
      }
      else if (line.startsWith("$")) { //$NON-NLS-1$
        final String blockName = line.substring(1);
        final BlockBuilder newBuilder = new BlockBuilder(blockName);
        builders.push(newBuilder);
      }
      else {
        final BlockBuilder builder = builders.peek();
        builder.addLine(line);
      }
    }
    catch (final IOException e) {
      throw new ParseException(lineIndex, line, e);
    }
  }

  private boolean isEquivalentBlockName(final String name1, final String name2) {
    final String s1 = name1.replaceAll(" *", " "); //$NON-NLS-1$ //$NON-NLS-2$
    final String s2 = name2.replaceAll(" *", " "); //$NON-NLS-1$ //$NON-NLS-2$
    return s1.equals(s2);
  }

  public Block createObject() {
    return board;
  }
}