/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcb.persistence.write;

import java.io.PrintWriter;
import java.util.List;

import de.jave.kicad.pcb.model.Block;
import de.jave.kicad.pcb.persistence.read.BlockBlockItem;
import de.jave.kicad.pcb.persistence.read.IBlockItem;
import de.jave.kicad.pcb.persistence.read.LineBlockItem;

public class BlockEncoder {

  public void encode(final PrintWriter printWriter, final Block block) {
    final String blockName = block.getBlockName();
    if (BlockFormatSpecification.isWriteStartTag(blockName)) {
      printWriter.println("$" + blockName); //$NON-NLS-1$
    }

    final List<IBlockItem> items = block.getItems();
    for (final IBlockItem item : items) {
      //TODO_NOW (gebhard) 14.01.2011: Visitor!!
      if (item instanceof BlockBlockItem) {
        final BlockBlockItem blockItem = (BlockBlockItem) item;
        encode(printWriter, blockItem.getBlock());
      }
      else if (item instanceof LineBlockItem) {
        final LineBlockItem lineItem = (LineBlockItem) item;
        final String line = lineItem.getLine();
        printWriter.println(line);
      }
    }
    String endTagName;
    final int firstSpaceIndex = blockName.indexOf(' ');
    if (firstSpaceIndex != -1) {
      endTagName = blockName.substring(0, firstSpaceIndex)
          + ' '
          + blockName.substring(firstSpaceIndex);
    }
    else {
      endTagName = blockName;
    }
    if (BlockFormatSpecification.isLowercaseEndTagStart(blockName)) {
      printWriter.println("$end" + endTagName);
    }
    else {
      printWriter.println("$End" + endTagName);
    }
  }
}