/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer;

import java.awt.Rectangle;
import java.awt.geom.AffineTransform;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.model.PositioningTransformation;

public class ContentTransformation {

  private final int dy;
  private final int dx;
  private final int rotation;

  public ContentTransformation(final int dx, final int dy, final int rotation) {
    this.dx = dx;
    this.dy = dy;
    this.rotation = rotation;
  }

  public int getDx() {
    return dx;
  }

  public int getDy() {
    return dy;
  }

  public int getRotation() {
    return rotation;
  }

  public static List<PositioningTransformation> convertToAffineTransformations(
      final List<ContentTransformation> transformations,
      final Rectangle boardBounds) {
    Ensure.ensureArgumentNotNull(transformations);
    Ensure.ensureArgumentNotNull(boardBounds);
    return CollectionUtilities.transform(
        transformations,
        new ITransformer<ContentTransformation, PositioningTransformation>() {
          @Override
          public PositioningTransformation transform(final ContentTransformation input) {
            final int dx = input.getDx();
            final int dy = input.getDy();
            final int rotation = input.getRotation();
            final AffineTransform t = new AffineTransform();
            t.translate(dx, dy);
            t.translate(boardBounds.x, boardBounds.y);
            final int angle;
            if (rotation == 0 || rotation == 360) {
              //nothing to do
              angle = 0;
            }
            else if (rotation == 180) {
              //(gebhard) 22.01.2011: Optimization for rectangular boards: no need to rotate 180
              //              t.rotate(Math.PI, 0, 0);
              //              t.translate(-boardBounds.width, -boardBounds.height);
              angle = 0;
            }
            else if (rotation == 90) {
              t.rotate(Math.PI / 2.0, 0, boardBounds.height);
              t.translate(-boardBounds.height, 0);
              angle = 90;
            }
            else {
              throw new UnsupportedOperationException("Rotation " //$NON-NLS-1$
                  + rotation
                  + " not supported yet."); //$NON-NLS-1$
            }
            t.translate(-boardBounds.x, -boardBounds.y);
            return new PositioningTransformation(t, angle);
          }
        });
  }
}