/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer;

import java.awt.Polygon;
import java.awt.Rectangle;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcb.model.PositioningTransformation;
import de.jave.kicad.pcbmultiplyer.tree.ISolution;

public class SolutionPolygonFactory {

  public static List<OrientedPolygon> createPolygons(
      final PcbMultiplySetup setup,
      final ISolution solution) {
    final List<ContentTransformation> transformations = solution.createTransformations();
    final List<PositioningTransformation> ts = ContentTransformation
        .convertToAffineTransformations(transformations, setup.getOriginalContentBounds());

    final List<OrientedPolygon> polygons = CollectionUtilities.transform(
        ts,
        new ITransformer<PositioningTransformation, OrientedPolygon>() {
          @Override
          public OrientedPolygon transform(final PositioningTransformation t) {
            final Polygon polygon = getOriginalContentPolygon(setup);
            SolutionPolygonFactory.transform(polygon, t);
            return new OrientedPolygon(polygon, t.getRotationAngle());
          }
        });
    sortByXY(polygons);
    return polygons;
  }

  private static Polygon getOriginalContentPolygon(final PcbMultiplySetup setup) {
    final Rectangle rectangle = setup.getOriginalContentBounds();
    final int[] xs = new int[]{
        rectangle.x,
        rectangle.x + rectangle.width,
        rectangle.x + rectangle.width,
        rectangle.x,
        rectangle.x };
    final int[] ys = new int[]{
        rectangle.y,
        rectangle.y,
        rectangle.y + rectangle.height,
        rectangle.y + rectangle.height,
        rectangle.y };
    return new Polygon(xs, ys, xs.length);
  }

  private static void transform(final Polygon polygon, final PositioningTransformation t) {
    t.transform(polygon.xpoints, polygon.ypoints, polygon.npoints);
  }

  private static void sortByXY(final List<OrientedPolygon> polygons) {
    Collections.sort(polygons, new Comparator<OrientedPolygon>() {
      @Override
      public int compare(final OrientedPolygon p1, final OrientedPolygon p2) {
        final Rectangle o1 = p1.getBounds();
        final Rectangle o2 = p2.getBounds();
        if (o1.y < o2.y) {
          return -1;
        }
        if (o1.y > o2.y) {
          return 1;
        }
        if (o1.x < o2.x) {
          return -1;
        }
        if (o1.x > o2.x) {
          return 1;
        }
        return 0;
      }
    });
  }
}