/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer;

import java.awt.Dimension;
import java.awt.Rectangle;

import net.disy.commons.core.util.Ensure;
import de.jave.kicad.pcbmultiplyer.tree.ISolution;

public class SolutionRater {

  private final PcbMultiplySetup setup;

  public SolutionRater(final PcbMultiplySetup setup) {
    Ensure.ensureArgumentNotNull(setup);
    this.setup = setup;
  }

  public double rate(final ISolution solution) {
    final int count = solution.getPcbCount();
    final long cutLength = getCutLength(solution);
    final double cutLengthRating = (double) cutLength
        / count
        / (setup.getOriginalContentBounds().width + setup.getOriginalContentBounds().height);
    return count * 100 - cutLengthRating;
  }

  private long getCutLength(final ISolution solution) {
    final Dimension solutionSize = solution.getSize();
    final Dimension targetSize = setup.getTargetBoardBounds().getSize();
    long cutLength = solution.getCutLength();
    if (solutionSize.width < targetSize.width) {
      cutLength += solutionSize.height;
    }
    if (solutionSize.height < targetSize.height) {
      cutLength += solutionSize.width;
    }
    return cutLength;
  }

  public boolean isFitsOnBoard(final ISolution solution) {
    final Dimension size = solution.getSize();
    final Rectangle targetBoardBounds = setup.getTargetBoardBounds();
    return size.width <= targetBoardBounds.width
        && size.height <= targetBoardBounds.height
        || size.height <= targetBoardBounds.width
        && size.width <= targetBoardBounds.height;
  }
}