/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import net.disy.commons.core.util.Ensure;
import net.disy.commons.swing.label.SmartLabel;
import net.disy.commons.swing.layout.grid.GridAlignment;
import net.disy.commons.swing.layout.grid.GridDialogLayout;
import net.disy.commons.swing.layout.grid.GridDialogLayoutData;
import net.disy.commons.swing.layout.util.LayoutUtilities;
import net.disy.commons.swing.ui.IObjectUi;
import net.disy.commons.swing.ui.ObjectUiListCellRenderer;
import de.jave.kicad.pcbmultiplyer.PcbMultiplyOptionsModel;

public class BoardSizeOptionsPanel {

  private final static List<Dimension> DEFAULT_SIZES = new ArrayList<Dimension>() {
    {
      add(new Dimension(100, 75));
      add(new Dimension(120, 80));
      add(new Dimension(160, 100));
      add(new Dimension(200, 100));
      add(new Dimension(200, 160));
      add(new Dimension(300, 200));
    }
  };

  private final JComponent content;

  public BoardSizeOptionsPanel(final PcbMultiplyOptionsModel model) {
    Ensure.ensureArgumentNotNull(model);
    final SpinnerNumberModel boardWidthModel = new SpinnerNumberModel(
        model.getBoardWidthMm(),
        10,
        1000,
        1);
    boardWidthModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setBoardWidthMm(boardWidthModel.getNumber().intValue());
      }
    });
    final SpinnerNumberModel boardHeightModel = new SpinnerNumberModel(
        model.getBoardHeightMm(),
        10,
        1000,
        1);
    boardHeightModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setBoardHeightMm(boardHeightModel.getNumber().intValue());
      }
    });
    final SpinnerNumberModel boardPriceModel = new SpinnerNumberModel(
        model.getBoardPrice(),
        0,
        100000,
        1);
    boardPriceModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setBoardPrice(boardPriceModel.getNumber().intValue());
      }
    });

    final GridDialogLayoutData fillLayoutData = new GridDialogLayoutData()
        .setHorizontalAlignment(GridAlignment.FILL);

    final Vector<Dimension> items = new Vector<Dimension>(DEFAULT_SIZES);
    items.add(0, null);
    final JComboBox comboBox = new JComboBox(items);
    comboBox.setRenderer(new ObjectUiListCellRenderer(new IObjectUi<Dimension>() {
      @Override
      public Icon getIcon(final Dimension value) {
        return null;
      }

      @Override
      public String getLabel(final Dimension value) {
        if (value == null) {
          return ""; //$NON-NLS-1$
        }
        return value.width + "mm x " + value.height + "mm";
      }

      @Override
      public String getToolTipText(final Dimension value) {
        return null;
      }
    }));
    comboBox.addActionListener(new ActionListener() {
      @SuppressWarnings("boxing")
      @Override
      public void actionPerformed(final ActionEvent e) {
        final Dimension item = (Dimension) comboBox.getSelectedItem();
        if (item == null) {
          return;
        }
        boardHeightModel.setValue(item.height);
        boardWidthModel.setValue(item.width);
        comboBox.setSelectedItem(null);
      }
    });

    final JSpinner heightSpinner = new JSpinner(boardHeightModel);
    final JSpinner widthSpinner = new JSpinner(boardWidthModel);
    final JSpinner priceSpinner = new JSpinner(boardPriceModel);

    final JPanel panel = new JPanel(new GridDialogLayout(3, false));
    panel.setBorder(LayoutUtilities.getDefaultEmptyBorder());
    panel.add(new JLabel("Standard sizes:"), GridDialogLayoutData.RIGHT);
    panel.add(comboBox, new GridDialogLayoutData().setHorizontalSpan(2));
    panel.add(new SmartLabel("&Width:", widthSpinner), GridDialogLayoutData.RIGHT);
    panel.add(widthSpinner, fillLayoutData);
    panel.add(new JLabel("mm"));
    panel.add(new SmartLabel("&Height:", heightSpinner), GridDialogLayoutData.RIGHT);
    panel.add(heightSpinner, fillLayoutData);
    panel.add(new JLabel("mm"));
    panel.add(new SmartLabel("&Price:", priceSpinner), GridDialogLayoutData.RIGHT);
    panel.add(priceSpinner, fillLayoutData);
    panel.add(new JLabel("ct/any unit"));
    this.content = panel;
  }

  public JComponent getContent() {
    return content;
  }
}