/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import net.disy.commons.core.util.Ensure;
import net.disy.commons.swing.label.SmartLabel;
import net.disy.commons.swing.layout.grid.GridAlignment;
import net.disy.commons.swing.layout.grid.GridDialogLayout;
import net.disy.commons.swing.layout.grid.GridDialogLayoutData;
import net.disy.commons.swing.layout.util.LayoutUtilities;
import de.jave.kicad.pcbmultiplyer.PcbMultiplyOptionsModel;

public class MultiplesOptionsPanel {

  private final JComponent content;

  public MultiplesOptionsPanel(final PcbMultiplyOptionsModel model) {
    Ensure.ensureArgumentNotNull(model);

    final SpinnerNumberModel multiplesXModel = new SpinnerNumberModel(
        model.getMultiplesX(),
        1,
        100,
        1);
    multiplesXModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setMultiplesX(multiplesXModel.getNumber().intValue());
      }
    });
    final SpinnerNumberModel multiplesYModel = new SpinnerNumberModel(
        model.getMultiplesY(),
        1,
        100,
        1);
    multiplesYModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setMultiplesY(multiplesYModel.getNumber().intValue());
      }
    });
    final JSpinner xSpinner = new JSpinner(multiplesXModel);
    final JSpinner ySpinner = new JSpinner(multiplesYModel);

    final GridDialogLayoutData fillLayoutData = new GridDialogLayoutData()
        .setHorizontalAlignment(GridAlignment.FILL);
    final JPanel panel = new JPanel(new GridDialogLayout(2, false));
    panel.setBorder(LayoutUtilities.getDefaultEmptyBorder());
    panel.add(new SmartLabel("&X-direction:", xSpinner), GridDialogLayoutData.RIGHT);
    panel.add(xSpinner, fillLayoutData);
    panel.add(new SmartLabel("&Y-direction:", ySpinner), GridDialogLayoutData.RIGHT);
    panel.add(ySpinner, fillLayoutData);
    this.content = panel;
  }

  public JComponent getContent() {
    return content;
  }
}