/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing;

import java.awt.event.KeyEvent;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JTabbedPane;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import net.disy.commons.swing.label.SmartLabel;
import net.disy.commons.swing.layout.grid.GridAlignment;
import net.disy.commons.swing.layout.grid.GridDialogLayout;
import net.disy.commons.swing.layout.grid.GridDialogLayoutData;
import de.jave.kicad.pcbmultiplyer.MultiplyMode;
import de.jave.kicad.pcbmultiplyer.PcbMultiplyOptionsModel;

public class OptionsPanel {

  private final JComponent content;

  public OptionsPanel(final PcbMultiplyOptionsModel model) {
    final SpinnerNumberModel spacingModel = new SpinnerNumberModel(
        model.getSpacingMm(),
        0.0,
        20.0,
        0.1);
    spacingModel.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        model.setSpacingMm(spacingModel.getNumber().doubleValue());
      }
    });

    final JTabbedPane tabbedPane = new JTabbedPane();
    tabbedPane.addTab("Target size", new BoardSizeOptionsPanel(model).getContent());
    tabbedPane.setMnemonicAt(0, KeyEvent.VK_T);

    tabbedPane.addTab("Multiples", new MultiplesOptionsPanel(model).getContent());
    tabbedPane.setMnemonicAt(1, KeyEvent.VK_M);

    final MultiplyMode mode = model.getMode();
    switch (mode) {
      case FIT_BOARD:
        tabbedPane.setSelectedIndex(0);
        break;
      case FIXED_MULTIPLES:
        tabbedPane.setSelectedIndex(1);
        break;
      default:
        throw new UnsupportedOperationException();
    }
    tabbedPane.addChangeListener(new ChangeListener() {
      @Override
      public void stateChanged(final ChangeEvent e) {
        switch (tabbedPane.getSelectedIndex()) {
          case 0:
            model.setMode(MultiplyMode.FIT_BOARD);
            break;
          case 1:
            model.setMode(MultiplyMode.FIXED_MULTIPLES);
            break;
          default:
            throw new UnsupportedOperationException();
        }
      }
    });
    final JSpinner spacingSpinner = new JSpinner(spacingModel);

    final GridDialogLayoutData fillLayoutData = new GridDialogLayoutData()
        .setHorizontalAlignment(GridAlignment.FILL);
    final JPanel panel = new JPanel(new GridDialogLayout(3, false));
    panel.add(tabbedPane, new GridDialogLayoutData().setHorizontalSpan(3));
    panel.add(new SmartLabel("&Spacing:", spacingSpinner), GridDialogLayoutData.RIGHT);
    panel.add(spacingSpinner, fillLayoutData);
    panel.add(new JLabel("mm"));
    this.content = panel;
  }

  public JComponent getContent() {
    return content;
  }
}