/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.FlowLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.WindowConstants;

import net.disy.commons.core.model.ObjectModel;
import net.disy.commons.core.model.listener.IChangeListener;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.swing.util.GuiUtilities;
import de.jave.kicad.pcb.model.KicadBoard;
import de.jave.kicad.pcbmultiplyer.PcbMultiplyOptionsModel;
import de.jave.kicad.pcbmultiplyer.PcbMultiplySetup;
import de.jave.kicad.pcbmultiplyer.preferences.PcbMultiplyPreferences;
import de.jave.kicad.pcbmultiplyer.swing.action.ApplyLayoutPerformer;
import de.jave.kicad.pcbmultiplyer.swing.action.LoadBoardAction;
import de.jave.kicad.pcbmultiplyer.swing.action.SaveResultToNewBoardAction;
import de.jave.kicad.pcbmultiplyer.tree.ISolution;

public class PcbMultiplyerApplication {

  private final JFrame frame = new JFrame("PCB Multiplyer v1.2 mk@jave.de");
  private final ObjectModel<KicadBoard> boardModel = new ObjectModel<KicadBoard>();
  private final ObjectModel<ISolution> solutionModel = new ObjectModel<ISolution>();
  private final ObjectModel<PcbMultiplySetup> setupModel = new ObjectModel<PcbMultiplySetup>();

  private final SaveResultToNewBoardAction saveAction;
  private final LoadBoardAction loadAction;
  private final PcbMultiplyOptionsModel optionsModel;
  private final ApplyLayoutPerformer applyPerformer;
  private final PcbMultiplyPreferences preferences;

  public PcbMultiplyerApplication(final PcbMultiplyPreferences preferences) {
    Ensure.ensureArgumentNotNull(preferences);
    this.preferences = preferences;
    this.optionsModel = preferences.getOptionsModel();
    applyPerformer = new ApplyLayoutPerformer(
        setupModel,
        solutionModel,
        boardModel,
        preferences.getOptionsModel());
    saveAction = new SaveResultToNewBoardAction(boardModel, solutionModel);
    loadAction = new LoadBoardAction(boardModel, applyPerformer);
  }

  public void show(final File inputFile) {
    final JPanel toolbarPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
    toolbarPanel.add(new JButton(loadAction));
    toolbarPanel.add(new JButton(saveAction));

    frame.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
    frame.addWindowListener(new WindowAdapter() {
      @Override
      public void windowClosing(final WindowEvent e) {
        performExit();
      }
    });
    frame.setIconImages(PcbMultiplyerIcons.ICON_IMAGES);
    final Container contentPane = frame.getContentPane();
    contentPane.setLayout(new BorderLayout());
    contentPane.add(new SolutionComponent(setupModel, solutionModel), BorderLayout.CENTER);
    contentPane.add(toolbarPanel, BorderLayout.NORTH);
    contentPane.add(new ControlPanel(optionsModel).getContent(), BorderLayout.WEST);
    contentPane.add(new StatusLine(setupModel, solutionModel).getContent(), BorderLayout.SOUTH);
    frame.pack();
    GuiUtilities.show(frame);
    if (inputFile != null) {
      loadAction.performLoad(frame, inputFile);
    }
    else {
      loadAction.execute(frame);
    }

    optionsModel.addChangeListener(new IChangeListener() {
      @Override
      public void stateChanged() {
        applyPerformer.execute(frame);
      }
    });
  }

  protected void performExit() {
    preferences.storeOptions();
    preferences.flush();
    System.exit(0);
  }
}