/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing;

import java.io.File;

import javax.swing.SwingUtilities;

import net.disy.commons.core.exception.CentralExceptionHandling;
import net.disy.commons.core.exception.IExceptionHandler;
import net.disy.commons.core.io.FileModel;
import net.disy.commons.core.message.Message;
import net.disy.commons.core.message.MessageType;
import net.disy.commons.swing.dialog.core.DialogDefaults;
import net.disy.commons.swing.dialog.message.MessageDialogFactory;
import net.disy.commons.swing.dialog.userdialog.UserDialog;
import net.disy.commons.swing.filechooser.IFileChooserProvider;
import net.disy.commons.swing.filechooser.SmartFileChooser;
import net.disy.commons.swing.filechooser.chooser.DefaultFileChooser;
import net.disy.commons.swing.filechooser.chooser.IFileChooser;
import net.disy.commons.swing.filechooser.workingdirectory.IWorkingDirectoryPreference;
import net.disy.commons.swing.laf.LookAndFeelUtilities;
import de.jave.kicad.pcbmultiplyer.preferences.PcbMultiplyPreferences;

public class PcbMultiplyerMain {

  public static void main(final String[] args) {
    final File inputFile = parseOptionalInputFile(args);

    SwingUtilities.invokeLater(new Runnable() {
      @Override
      public void run() {
        LookAndFeelUtilities.setSystemLookAndFeel();
        DialogDefaults.getInstance().setFrameIconImages(PcbMultiplyerIcons.ICON_IMAGES);
        initializeCentralExceptionHandling();
        final PcbMultiplyPreferences preferences = new PcbMultiplyPreferences();
        initializeFileChooser(preferences.getCurrentDirectoryModel());
        final PcbMultiplyerApplication application = new PcbMultiplyerApplication(preferences);
        application.show(inputFile);
      }
    });
  }

  private static File parseOptionalInputFile(final String[] args) {
    if (args.length == 0) {
      return null;
    }
    if (args.length > 1) {
      System.err.println("Only a single file name argument is allowed, was "
          + args.length
          + " arguments given.");
      System.exit(1);
    }
    final String fileName = args[0];
    final File file = new File(fileName);
    if (!file.exists()) {
      System.err.println("File does not exist: '");
      System.err.println(fileName);
      System.err.println("'");
      System.exit(1);
    }
    return file;
  }

  private static void initializeFileChooser(final FileModel currentDirectoryModel) {
    final DefaultFileChooser defaultFileChooser = new DefaultFileChooser();
    final SmartFileChooser instance = SmartFileChooser.getInstance();
    instance.setWorkingDirectoryPreference(new IWorkingDirectoryPreference() {
      @Override
      public File getWorkingDirectory() {
        return currentDirectoryModel.getValue();
      }

      @Override
      public void setWorkingDirectory(final File workingDirectory) {
        currentDirectoryModel.setValue(workingDirectory);
      }
    });
    instance.setFileChooserProvider(new IFileChooserProvider() {
      @Override
      public IFileChooser getFileChooser() {
        return defaultFileChooser;
      }
    });
  }

  private static void initializeCentralExceptionHandling() {
    CentralExceptionHandling.setHandler(new IExceptionHandler() {
      @Override
      public void handle(final Throwable exception) {
        exception.printStackTrace();
        SwingUtilities.invokeLater(new Runnable() {
          @Override
          public void run() {
            final UserDialog dialog = MessageDialogFactory.createMessageDialog(null, new Message(
                "PCB Multiplyer Error",
                "An exception has occurred.",
                MessageType.ERROR,
                exception));
            dialog.getDialog().setModal(false);
            dialog.show();
          }
        });
      }
    });
  }
}