/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.swing.action;

import java.awt.Component;
import java.io.File;
import java.io.IOException;

import net.disy.commons.core.message.Message;
import net.disy.commons.core.model.ObjectModel;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.swing.action.SmartAction;
import net.disy.commons.swing.dialog.message.MessageDialogFactory;
import net.disy.commons.swing.filechooser.SmartFileChooser;
import net.disy.commons.swing.filechooser.result.IFileChooserOpenResult;
import de.jave.kicad.pcb.model.KicadBoard;
import de.jave.kicad.pcb.persistence.read.KicadPcbFileParser;
import de.jave.kicad.pcbmultiplyer.swing.KicadBoardFileFileChooserConfiguration;

public class LoadBoardAction extends SmartAction {

  private final ApplyLayoutPerformer applyPerformer;
  private final ObjectModel<KicadBoard> boardModel;

  public LoadBoardAction(
      final ObjectModel<KicadBoard> boardModel,
      final ApplyLayoutPerformer applyPerformer) {
    super("&Load Board...");
    Ensure.ensureArgumentNotNull(boardModel);
    Ensure.ensureArgumentNotNull(applyPerformer);
    this.applyPerformer = applyPerformer;
    this.boardModel = boardModel;
  }

  @Override
  public void execute(final Component parentComponent) {
    final IFileChooserOpenResult result = SmartFileChooser.getInstance().performOpenFileChooser(
        parentComponent,
        new KicadBoardFileFileChooserConfiguration());
    if (result.isCanceled()) {
      return;
    }
    final File inputFile = result.getSelectedFile();
    performLoad(parentComponent, inputFile);
  }

  public void performLoad(final Component parentComponent, final File inputFile) {
    KicadBoard pcb = null;
    try {
      pcb = KicadPcbFileParser.parse(inputFile);
    }
    catch (final IOException e) {
      MessageDialogFactory.showMessageDialog(parentComponent, new Message(
          "Error reading input file.",
          e));
      return;
    }
    boardModel.setValue(pcb);
    applyPerformer.execute(parentComponent);
  }
}