/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.tree;

import java.awt.Dimension;
import java.util.ArrayList;
import java.util.List;

import net.disy.commons.core.util.Ensure;
import de.jave.kicad.pcbmultiplyer.ContentTransformation;

public class AddVerticalSolution implements ISolution {

  private final ISolution solution2;
  private final ISolution solution1;
  private final int spacing;
  private final Dimension size;

  public AddVerticalSolution(final ISolution solution1, final ISolution solution2, final int spacing) {
    Ensure.ensureArgumentNotNull(solution1);
    Ensure.ensureArgumentNotNull(solution2);
    this.solution1 = solution1;
    this.solution2 = solution2;
    this.spacing = spacing;
    //(gebhard) 24.01.2011: for performance reasons we only calculate the size once!
    size = calculateSize();
  }

  @Override
  public int getPcbCount() {
    return solution1.getPcbCount() + solution2.getPcbCount();
  }

  @Override
  public Dimension getSize() {
    return size;
  }

  private Dimension calculateSize() {
    final Dimension solutionSize1 = solution1.getSize();
    final Dimension solutionSize2 = solution2.getSize();
    final int height = solutionSize1.height + solutionSize2.height + spacing;
    final int width = Math.max(solutionSize1.width, solutionSize2.width);
    return new Dimension(width, height);
  }

  @Override
  public List<ContentTransformation> createTransformations() {
    final List<ContentTransformation> results = new ArrayList<ContentTransformation>(
        solution1.createTransformations());
    final List<ContentTransformation> transformations = solution2.createTransformations();
    final int dy = solution1.getSize().height + spacing;
    for (final ContentTransformation transformation : transformations) {
      results.add(new ContentTransformation(
          transformation.getDx(),
          transformation.getDy() + dy,
          transformation.getRotation()));
    }
    return results;
  }

  @Override
  public long getCutLength() {
    long additionalLength;
    if (solution1.getSize().width > solution2.getSize().width) {
      additionalLength = solution1.getSize().width + solution2.getSize().height;
    }
    else if (solution2.getSize().width > solution1.getSize().width) {
      additionalLength = solution2.getSize().width + solution1.getSize().height;
    }
    else {
      additionalLength = solution1.getSize().width;
    }
    return solution1.getCutLength() + solution2.getCutLength() + additionalLength;
  }
}