/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.tree;

import java.awt.Dimension;
import java.util.ArrayList;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcbmultiplyer.ContentTransformation;

public class MultiplySolution implements ISolution {

  private final ISolution solution;
  private final int spacing;
  private final Dimension size;
  private final int xCount;
  private final int yCount;

  public MultiplySolution(
      final ISolution solution,
      final int xCount,
      final int yCount,
      final int spacing) {
    Ensure.ensureArgumentNotNull(solution);
    this.solution = solution;
    this.spacing = spacing;
    this.xCount = xCount;
    this.yCount = yCount;
    //(gebhard) 24.01.2011: for performance reasons we only calculate the size once!
    size = calculateSize();
  }

  @Override
  public int getPcbCount() {
    return xCount * yCount * solution.getPcbCount();
  }

  @Override
  public Dimension getSize() {
    return size;
  }

  private Dimension calculateSize() {
    final Dimension solutionSize = solution.getSize();
    return new Dimension(solutionSize.width * xCount + spacing * (xCount - 1), solutionSize.height
        * yCount
        + spacing
        * (yCount - 1));
  }

  @Override
  public List<ContentTransformation> createTransformations() {
    final List<ContentTransformation> transformations = solution.createTransformations();
    final List<ContentTransformation> results = new ArrayList<ContentTransformation>();
    final int dx = solution.getSize().width + spacing;
    final int dy = solution.getSize().height + spacing;
    for (int x = 0; x < xCount; ++x) {
      for (int y = 0; y < yCount; ++y) {
        final int xIndex = x;
        final int yIndex = y;
        results.addAll(CollectionUtilities.transform(
            transformations,
            new ITransformer<ContentTransformation, ContentTransformation>() {
              @Override
              public ContentTransformation transform(final ContentTransformation input) {
                return new ContentTransformation(input.getDx() + xIndex * dx, input.getDy()
                    + yIndex
                    * dy, input.getRotation());
              }
            }));
      }
    }
    return results;
  }

  @Override
  public long getCutLength() {
    return xCount
        * yCount
        * solution.getCutLength()
        + (xCount - 1)
        * solution.getSize().height
        + (yCount - 1)
        * solution.getSize().width;
  }
}