/**
 * Copyright (C) 2011 Markus Gebhard (mk@jave.de) and others
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 */
package de.jave.kicad.pcbmultiplyer.tree;

import java.awt.Dimension;
import java.util.List;

import net.disy.commons.core.util.CollectionUtilities;
import net.disy.commons.core.util.Ensure;
import net.disy.commons.core.util.ITransformer;
import de.jave.kicad.pcbmultiplyer.ContentTransformation;

public class RotateSolution implements ISolution {

  private final ISolution solution;
  private final Dimension size;

  public RotateSolution(final ISolution solution) {
    Ensure.ensureArgumentNotNull(solution);
    this.solution = solution;
    //(gebhard) 24.01.2011: for performance reasons we only calculate the size once!
    final Dimension solutionSize = solution.getSize();
    size = new Dimension(solutionSize.height, solutionSize.width);
  }

  @Override
  public int getPcbCount() {
    return solution.getPcbCount();
  }

  @Override
  public Dimension getSize() {
    return size;
  }

  @Override
  public List<ContentTransformation> createTransformations() {
    final List<ContentTransformation> transformations = solution.createTransformations();
    return CollectionUtilities.transform(
        transformations,
        new ITransformer<ContentTransformation, ContentTransformation>() {
          @Override
          public ContentTransformation transform(final ContentTransformation input) {
            return new ContentTransformation(
                input.getDy(),
                input.getDx(),
                (input.getRotation() + 90) % 360);
          }
        });
  }

  @Override
  public long getCutLength() {
    return solution.getCutLength();
  }
}